wallaroo.wallaroo_ml_ops_api_client.models.assays_run_interactive_response_200_item_summarizer_type_1 API documentation

# wallaroo.wallaroo_ml_ops_api_client.models.assays_run_interactive_response_200_item_summarizer_type_1

View Source

     1from typing import Any, Dict, List, Type, TypeVar
     2
     3import attr
     4
     5from ..models.assays_run_interactive_response_200_item_summarizer_type_1_type import \
     6    AssaysRunInteractiveResponse200ItemSummarizerType1Type
     7
     8T = TypeVar("T", bound="AssaysRunInteractiveResponse200ItemSummarizerType1")
     9
    10@attr.s(auto_attribs=True)
    11class AssaysRunInteractiveResponse200ItemSummarizerType1:
    12    """
    13    Attributes:
    14        name (str):
    15        type (AssaysRunInteractiveResponse200ItemSummarizerType1Type):
    16    """
    17
    18    name: str
    19    type: AssaysRunInteractiveResponse200ItemSummarizerType1Type
    20    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
    21
    22
    23    def to_dict(self) -> Dict[str, Any]:
    24        name = self.name
    25        type = self.type.value
    26
    27
    28        field_dict: Dict[str, Any] = {}
    29        field_dict.update(self.additional_properties)
    30        field_dict.update({
    31            "name": name,
    32            "type": type,
    33        })
    34
    35        return field_dict
    36
    37
    38
    39    @classmethod
    40    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    41        d = src_dict.copy()
    42        name = d.pop("name")
    43
    44        type = AssaysRunInteractiveResponse200ItemSummarizerType1Type(d.pop("type"))
    45
    46
    47
    48
    49        assays_run_interactive_response_200_item_summarizer_type_1 = cls(
    50            name=name,
    51            type=type,
    52        )
    53
    54        assays_run_interactive_response_200_item_summarizer_type_1.additional_properties = d
    55        return assays_run_interactive_response_200_item_summarizer_type_1
    56
    57    @property
    58    def additional_keys(self) -> List[str]:
    59        return list(self.additional_properties.keys())
    60
    61    def __getitem__(self, key: str) -> Any:
    62        return self.additional_properties[key]
    63
    64    def __setitem__(self, key: str, value: Any) -> None:
    65        self.additional_properties[key] = value
    66
    67    def __delitem__(self, key: str) -> None:
    68        del self.additional_properties[key]
    69
    70    def __contains__(self, key: str) -> bool:
    71        return key in self.additional_properties

@attr.s(auto_attribs=True)
class AssaysRunInteractiveResponse200ItemSummarizerType1: View Source

    11@attr.s(auto_attribs=True)
    12class AssaysRunInteractiveResponse200ItemSummarizerType1:
    13    """
    14    Attributes:
    15        name (str):
    16        type (AssaysRunInteractiveResponse200ItemSummarizerType1Type):
    17    """
    18
    19    name: str
    20    type: AssaysRunInteractiveResponse200ItemSummarizerType1Type
    21    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
    22
    23
    24    def to_dict(self) -> Dict[str, Any]:
    25        name = self.name
    26        type = self.type.value
    27
    28
    29        field_dict: Dict[str, Any] = {}
    30        field_dict.update(self.additional_properties)
    31        field_dict.update({
    32            "name": name,
    33            "type": type,
    34        })
    35
    36        return field_dict
    37
    38
    39
    40    @classmethod
    41    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    42        d = src_dict.copy()
    43        name = d.pop("name")
    44
    45        type = AssaysRunInteractiveResponse200ItemSummarizerType1Type(d.pop("type"))
    46
    47
    48
    49
    50        assays_run_interactive_response_200_item_summarizer_type_1 = cls(
    51            name=name,
    52            type=type,
    53        )
    54
    55        assays_run_interactive_response_200_item_summarizer_type_1.additional_properties = d
    56        return assays_run_interactive_response_200_item_summarizer_type_1
    57
    58    @property
    59    def additional_keys(self) -> List[str]:
    60        return list(self.additional_properties.keys())
    61
    62    def __getitem__(self, key: str) -> Any:
    63        return self.additional_properties[key]
    64
    65    def __setitem__(self, key: str, value: Any) -> None:
    66        self.additional_properties[key] = value
    67
    68    def __delitem__(self, key: str) -> None:
    69        del self.additional_properties[key]
    70
    71    def __contains__(self, key: str) -> bool:
    72        return key in self.additional_properties

Attributes: name (str): type (AssaysRunInteractiveResponse200ItemSummarizerType1Type):

AssaysRunInteractiveResponse200ItemSummarizerType1( name: str, type: wallaroo.wallaroo_ml_ops_api_client.models.assays_run_interactive_response_200_item_summarizer_type_1_type.AssaysRunInteractiveResponse200ItemSummarizerType1Type) View Source

    2def __init__(self, name, type):
    3    self.name = name
    4    self.type = type
    5    self.additional_properties = __attr_factory_additional_properties()

Method generated by attrs for class AssaysRunInteractiveResponse200ItemSummarizerType1.

def to_dict(self) -> Dict[str, Any]: View Source

    24    def to_dict(self) -> Dict[str, Any]:
    25        name = self.name
    26        type = self.type.value
    27
    28
    29        field_dict: Dict[str, Any] = {}
    30        field_dict.update(self.additional_properties)
    31        field_dict.update({
    32            "name": name,
    33            "type": type,
    34        })
    35
    36        return field_dict

@classmethod
def from_dict(cls: Type[~T], src_dict: Dict[str, Any]) -> ~T: View Source

    40    @classmethod
    41    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    42        d = src_dict.copy()
    43        name = d.pop("name")
    44
    45        type = AssaysRunInteractiveResponse200ItemSummarizerType1Type(d.pop("type"))
    46
    47
    48
    49
    50        assays_run_interactive_response_200_item_summarizer_type_1 = cls(
    51            name=name,
    52            type=type,
    53        )
    54
    55        assays_run_interactive_response_200_item_summarizer_type_1.additional_properties = d
    56        return assays_run_interactive_response_200_item_summarizer_type_1

additional_keys: List[str]